svn commit: r231914 - head/sys/dev/mii

Marius Strobl marius at FreeBSD.org
Sun Feb 19 12:25:59 UTC 2012


Author: marius
Date: Sun Feb 19 12:25:58 2012
New Revision: 231914
URL: http://svn.freebsd.org/changeset/base/231914

Log:
  Probe the National DP83849, which is a dual-port version of the PHYTER.
  
  Obtained from:	NetBSD

Modified:
  head/sys/dev/mii/miidevs
  head/sys/dev/mii/nsphyter.c

Modified: head/sys/dev/mii/miidevs
==============================================================================
--- head/sys/dev/mii/miidevs	Sun Feb 19 12:09:17 2012	(r231913)
+++ head/sys/dev/mii/miidevs	Sun Feb 19 12:25:58 2012	(r231914)
@@ -1,5 +1,5 @@
 $FreeBSD$
-/*$NetBSD: miidevs,v 1.104 2011/11/12 11:10:49 sekiya Exp $*/
+/*$NetBSD: miidevs,v 1.105 2011/11/25 23:28:14 jakllsch Exp $*/
 
 /*-
  * Copyright (c) 1998, 1999 The NetBSD Foundation, Inc.
@@ -280,6 +280,7 @@ model xxNATSEMI DP83847		0x0003 DP83847 
 model xxNATSEMI DP83891		0x0005 DP83891 1000BASE-T media interface
 model xxNATSEMI DP83861		0x0006 DP83861 1000BASE-T media interface
 model xxNATSEMI DP83865		0x0007 DP83865 1000BASE-T media interface
+model xxNATSEMI DP83849		0x000a DP83849 10/100 media interface
 
 /* PMC Sierra PHYs */
 model xxPMCSIERRA PM8351	0x0000 PM8351 OctalPHY Gigabit interface

Modified: head/sys/dev/mii/nsphyter.c
==============================================================================
--- head/sys/dev/mii/nsphyter.c	Sun Feb 19 12:09:17 2012	(r231913)
+++ head/sys/dev/mii/nsphyter.c	Sun Feb 19 12:25:58 2012	(r231914)
@@ -58,8 +58,9 @@
 __FBSDID("$FreeBSD$");
 
 /*
  * driver for National Semiconductor's DP83843 `PHYTER' ethernet 10/100 PHY
  * Data Sheet available from www.national.com
  *
  * We also support the DP83815 `MacPHYTER' internal PHY since, for our
  * purposes, they are compatible.
@@ -114,6 +115,7 @@ static const struct mii_phydesc nsphyter
 	MII_PHY_DESC(xxNATSEMI, DP83815),
 	MII_PHY_DESC(xxNATSEMI, DP83843),
 	MII_PHY_DESC(xxNATSEMI, DP83847),
+	MII_PHY_DESC(xxNATSEMI, DP83849),
 	MII_PHY_END
 };
 
@@ -58,8 +58,9 @@
 
 /*
- * driver for National Semiconductor's DP83843 `PHYTER' ethernet 10/100 PHY
- * Data Sheet available from www.national.com
+ * Driver for the National Semiconductor's DP83843, DP83847 and DP83849
+ * `PHYTER' Ethernet 10/100 PHYs
+ * Data Sheets are available from http://www.national.com
  *
  * We also support the DP83815 `MacPHYTER' internal PHY since, for our


More information about the svn-src-all mailing list